pub trait InputRegionOptions {
// Required methods
fn region_filter(&self) -> &Option<Bed3<i32, u64>>;
fn region_filter_genomic_string(&self) -> Option<GenomicRegion>;
fn set_region_filter(&mut self, _value: Option<Bed3<i32, u64>>);
// Provided methods
fn is_full_overlap(&self) -> bool { ... }
fn convert_region_to_bed3(
&mut self,
header: HeaderView,
) -> Result<(), Error> { ... }
}Expand description
Retrieves options for region
Required Methods
Sourcefn region_filter_genomic_string(&self) -> Option<GenomicRegion>
fn region_filter_genomic_string(&self) -> Option<GenomicRegion>
returns region requested but region in genomic string format
Provided Methods
Sourcefn is_full_overlap(&self) -> bool
fn is_full_overlap(&self) -> bool
returns true if full overlap with region is requested as opposed to only partial overlap. defaults to false.
Sourcefn convert_region_to_bed3(&mut self, header: HeaderView) -> Result<(), Error>
fn convert_region_to_bed3(&mut self, header: HeaderView) -> Result<(), Error>
converts region from genomic string representation to bed3 representation
Errors
Returns error if conversion fails
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".