DNA complement and reverse-complement helpers.
This module includes code adapted from the bio crate’s DNA alphabet
utilities. See THIRD_PARTY_NOTICES.md for the upstream license text.
Functions
- complement
- Return the DNA complement of a byte while preserving
bio’s permissive behavior. - revcomp
- Return the reverse complement of an input byte sequence.