revcomp

Function revcomp 

pub fn revcomp<C, T>(text: T) -> Vec<u8> 
where C: Borrow<u8>, T: IntoIterator<Item = C>, T::IntoIter: DoubleEndedIterator,
Return the reverse complement of an input byte sequence.

The fast path (.collect()) is only taken when the iterator’s reported upper-bound length is within a safe pre-reservation budget. Larger reported lengths are refused and return an empty Vec instead.